[Asterisk-code-review] spelling: segment (asterisk[master])

Josh Soref asteriskteam at digium.com
Sun Nov 7 00:16:37 CDT 2021


Josh Soref has uploaded this change for review. ( https://gerrit.asterisk.org/c/asterisk/+/17184 )


Change subject: spelling: segment
......................................................................

spelling: segment

Change-Id: I6acf207e9bd2ee8b8e357a53c9b5f2529d90b193
---
M include/asterisk/ari.h
M rest-api-templates/asterisk_processor.py
2 files changed, 5 insertions(+), 5 deletions(-)



  git pull ssh://gerrit.asterisk.org:29418/asterisk refs/changes/84/17184/1

diff --git a/include/asterisk/ari.h b/include/asterisk/ari.h
index 7f06db0..9777b8f 100644
--- a/include/asterisk/ari.h
+++ b/include/asterisk/ari.h
@@ -66,12 +66,12 @@
  * \brief Handler for a single RESTful path segment.
  */
 struct stasis_rest_handlers {
-	/*! Path segement to handle */
+	/*! Path segment to handle */
 	const char *path_segment;
 	/*! If true (non-zero), path_segment is a wildcard, and will match all
 	 * values.
 	 *
-	 * Value of the segement will be passed into the \a path_vars parameter
+	 * Value of the segment will be passed into the \a path_vars parameter
 	 * of the callback.
 	 */
 	int is_wildcard;
diff --git a/rest-api-templates/asterisk_processor.py b/rest-api-templates/asterisk_processor.py
index ad88ebb..a47e63a 100644
--- a/rest-api-templates/asterisk_processor.py
+++ b/rest-api-templates/asterisk_processor.py
@@ -32,9 +32,9 @@
 
 
 def simple_name(name):
     """Removes the {markers} from a path segement.
 
-    @param name: Swagger path segement, with {pathVar} markers.
+    @param name: Swagger path segment, with {pathVar} markers.
     """
     if name.startswith('{') and name.endswith('}'):
         return name[1:-1]
@@ -84,7 +84,7 @@
         self.full_name = None
         #: Dictionary of child PathSegements
         self.__children = OrderedDict()
         #: List of operations on this segement
         self.operations = []
 
         if self.name != name:
@@ -32,9 +32,9 @@
 
 def simple_name(name):
-    """Removes the {markers} from a path segement.
+    """Removes the {markers} from a path segment.
 
@@ -84,7 +84,7 @@
         #: Dictionary of child PathSegements
         self.__children = OrderedDict()
-        #: List of operations on this segement
+        #: List of operations on this segment
         self.operations = []
 

-- 
To view, visit https://gerrit.asterisk.org/c/asterisk/+/17184
To unsubscribe, or for help writing mail filters, visit https://gerrit.asterisk.org/settings

Gerrit-Project: asterisk
Gerrit-Branch: master
Gerrit-Change-Id: I6acf207e9bd2ee8b8e357a53c9b5f2529d90b193
Gerrit-Change-Number: 17184
Gerrit-PatchSet: 1
Gerrit-Owner: Josh Soref <jsoref at gmail.com>
Gerrit-CC: Friendly Automation
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.digium.com/pipermail/asterisk-code-review/attachments/20211107/f80f9c60/attachment-0001.html>


More information about the asterisk-code-review mailing list